@@ -138,3 +138,28 @@ sub read_dir {
 ########################################################################
 
 1;
+
+__END__
+
+=head1 NAME
+
+Class::MakeMethods::Template::DiskCache - Optional Template feature
+
+=head1 SYNOPSIS
+
+  use Class::MakeMethods::Template::DiskCache qw( /my/code/dir );
+
+=head1 DESCRIPTION
+
+To enable disk caching of Class::MakeMethods::Template generated
+code, create an empty directory and pass it to the DiskCache package:
+
+  use Class::MakeMethods::Template::DiskCache qw( /my/code/dir );
+
+This has a mixed effect on performance, but has the notable advantage of letting you view the subroutines that are being generated by your templates.
+
+=head1 SEE ALSO
+
+See L<Class::MakeMethods::Template> for more information.
+
+=cut
\ No newline at end of file
